@@ -27,6 +27,6 @@ pub use crate::miner_list::MinerList;
 pub use crate::request::StratumRequest;
 pub use crate::result::StratumResult;
 pub use crate::server::StratumServer;
-pub use crate::types::{ReadyIndicator, ID};
+pub use crate::types::{ExMessageGeneric, MessageTypes, MessageValue, ReadyIndicator, ID};
 
 pub type Result<T> = std::result::Result<T, Error>;
