@@ -1,4 +1,5 @@
 use crate::route::{DynEndpoint, Endpoint};
+use crate::types::MessageValue;
 use crate::{Connection, StratumRequest};
 use async_std::sync::Arc;
 use std::collections::HashMap;
@@ -23,7 +24,7 @@ impl<State: Clone + Send + Sync + 'static, CState: Clone + Send + Sync + 'static
     pub async fn call(
         &self,
         method: &str,
-        values: serde_json::map::Map<String, serde_json::Value>,
+        value: MessageValue,
         state: State,
         connection: Arc<Connection<CState>>,
     ) {
@@ -32,7 +33,10 @@ impl<State: Clone + Send + Sync + 'static, CState: Clone + Send + Sync + 'static
             None => return,
         };
 
-        let request = StratumRequest { state, values };
+        let request = StratumRequest {
+            state,
+            values: value,
+        };
 
         endpoint.call(request, connection).await;
     }
